## RusticML

A machine learning framework written in Python that demonstrates the inner workings of frameworks like Pytorch and TensorFlow.

### Features

- Supports auto-diff backward propagation
- Supports implementation of Multi-layer Perceptron
- Supports popular activation functions such as Tanh, ReLU and Sigmoid